CSG to CAD Translation
======================

GEOUNED can be used as a Python package with the API or as a command line tool with the CLI.


.. toctree::
   :maxdepth: 1

   python_csgtocad_api_usage
   python_csgtocad_cli_usage
